/// <reference types="node" />
import sharp, { type Sharp } from "sharp";
declare type TImage = Buffer | string;
interface IGetImageSizeReturn {
    height: number;
    width: number;
    type?: string;
}
interface ILoadImageImg extends IGetImageSizeReturn {
    src: string;
}
interface ILoadImageOptions {
    dir?: string;
}
interface ILoadImageReturn {
    img: ILoadImageImg;
    file: TImage;
}
declare type SharpFormatOptions = Parameters<Sharp["toFormat"]>;
declare type SharpModulateOptions = Parameters<Sharp["modulate"]>[0];
interface IOptimizeImageOptions extends SharpModulateOptions {
    size?: number;
    format?: SharpFormatOptions;
    removeAlpha?: boolean;
}
interface IOptimizeImageReturn extends Record<"optimizedForBase64" | "optimizedForBlurhash" | "optimizedForCSS" | "optimizedForSVG", {
    data: Buffer;
    info: sharp.OutputInfo;
    rawBuffer: number[];
    rows: number[][][];
}> {
}
export declare type TGetImageSrc = TImage;
export interface IGetImageOptions extends ILoadImageOptions, IOptimizeImageOptions {
}
export interface IGetImageReturn extends Omit<ILoadImageReturn, "file">, IOptimizeImageReturn {
}
export interface IGetImage {
    (src: TGetImageSrc, options?: IGetImageOptions): Promise<IGetImageReturn>;
}
export declare const getImage: IGetImage;
export {};
